"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Debug = require("debug");
const debug = Debug("service:googlestorage");
const storage_1 = require("@google-cloud/storage");
class GoogleStorage {
    constructor(config = {}) {
        this.config = config;
        this.storage = new storage_1.Storage(this.config.client);
        this.bucket = this.storage.bucket(this.config.bucketName);
        debug("Ready for", this.config.client.projectId, this.config.bucketName);
    }
    async init() {
        debug("Checking if bucket exists..");
        try {
            const data = await this.bucket.exists();
            if (!data || !data[0]) {
                debug("Bucket does not exist.");
                return 0;
            }
            debug("Bucket exists.");
            return 1;
        }
        catch (error) {
            debug("Bucket does not exist", error.message);
            return 0;
        }
    }
    getStoreStream(filePath, contentType) {
        debug("Creating stream", filePath);
        const blob = this.bucket.file(filePath);
        const blobStream = blob.createWriteStream({
            metadata: {
                contentType,
            },
            gzip: true,
            public: false,
            private: false,
            resumable: true,
        });
        const promise = new Promise((resolve, reject) => {
            blobStream.on("error", (error) => {
                debug("Error during file stream", filePath, error.message);
                reject(error);
            });
            blobStream.on("finish", () => {
                debug("Finished stream", filePath);
                resolve();
            });
        });
        return {
            promise,
            end: () => {
                debug("Stream end called..");
                blobStream.end();
            },
            write: (chunk) => {
                debug("Stream chunk written..");
                blobStream.write(chunk);
            },
        };
    }
    getMetadata(filePath) {
        debug("Requesting metadata", filePath);
        const blob = this.bucket.file(filePath);
        return blob.getMetadata().then((results) => {
            return results[0];
        });
    }
    deleteFile(filePath) {
        debug("Deleting file", filePath);
        const blob = this.bucket.file(filePath);
        return blob.delete();
    }
}
exports.default = GoogleStorage;
