"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Debug = require("debug");
const debug = Debug("service:httpclient");
const request = require("request");
class HttpClient {
    static call(options) {
        debug("Calling", options);
        const startT = Date.now();
        return new Promise((resolve, reject) => {
            request(options, (error, response, body) => {
                if (error) {
                    debug("Request failed", error.message);
                    return reject(error);
                }
                const diffMs = Date.now() - startT;
                debug("Resolved", response.statusCode, "took", diffMs, "ms");
                resolve({
                    status: response.statusCode,
                    headers: response.headers,
                    body,
                });
            });
        });
    }
    static getRequestStream(options) {
        debug("Calling for stream", options);
        const startT = Date.now();
        return request(options)
            .on("error", (error) => {
            debug("Request failed", error.message);
        })
            .on("response", (response) => {
            const diffMs = Date.now() - startT;
            debug("Resolved", response.statusCode, response.headers["content-type"], "took", diffMs, "ms");
        });
    }
}
exports.default = HttpClient;
