"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const express = require("express");
const routeRoot = (service) => {
    const router = express.Router();
    router.get("/", (req, res) => {
        res.json({
            Hi: "Welcome to kratos!",
            parent: "/",
            self: "/",
            children: [
                "/api",
                "/doc",
                "/healthcheck",
                "/health",
                "/ready",
                "/metrics",
            ],
        });
    });
    router.get("/api", (req, res) => {
        res.json({
            parent: "/",
            self: "/api",
            children: [
                "/api/transaction",
            ],
        });
    });
    router.get("/doc", (req, res) => {
        res.end("Coming soon..");
    });
    router.get("/healthcheck", (req, res) => {
        res.status(service.isAlive() ? 200 : 503).end();
    });
    router.get("/health", (req, res) => {
        const [status, body] = service.getHealthInfo();
        res.status(status).json(body);
    });
    router.get("/ready", (req, res) => {
        res.status(service.isReady() ? 200 : 503).end();
    });
    router.get("/metrics", (req, res) => {
        res.set("content-type", service.metrics.exportType());
        res.end(service.metrics.exportMetrics());
    });
    return router;
};
exports.routeRoot = routeRoot;
